import Flutter
import UIKit
import ZendeskSDK
import ZendeskCoreSDK


public class SwiftFlutterZenDeskPlugin: NSObject, FlutterPlugin {
    
    var hcConfig: HelpCenterUiConfiguration {
        let hcConfig = HelpCenterUiConfiguration()
        hcConfig.showContactOptionsOnEmptySearch = true
        hcConfig.labels = ["label"] // only hc articles with the label 'label' will appear
        return hcConfig
    }
    
    var requestConfig: RequestUiConfiguration {
        let config = RequestUiConfiguration()
        config.tags = ["tag_1","tag_2", "tag_3"]
        config.subject = "Support_API Sample"
        return config
    }
    
    private var flutterResult:FlutterResult?

    private var aObjNavi: UINavigationController?

    private var helpCenter: UIViewController? = UIViewController.init()
    




    public static func register(with registrar: FlutterPluginRegistrar) {
        print("fun refister initialising plugin");
        let channel = FlutterMethodChannel(name: "flutter_zendesk", binaryMessenger: registrar.messenger())
        
       
        let instance = SwiftFlutterZenDeskPlugin()

        registrar.addMethodCallDelegate(instance, channel: channel)
        
    }
   
    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        print("handle methodcall")
        result("SUCCESS")

//        flutterResult = result
//
//        if(call.method.elementsEqual("initiate")){
//
//            let args = call.arguments as? NSDictionary
//
//            beginZendesk(arguements: args!)
//
//        }else{
//            flutterResult!(FlutterMethodNotImplemented)
//
//        }
    }
    
    func beginZendesk(arguements :NSDictionary) {
        print("begin zendesk")
        let args = arguements
        
        let appId = args["appId"]as? String
        let clientId  = args["clientId"]as? String
        let url = args["url"]as? String
        
        Zendesk.initialize(appId: appId!,
                           clientId: clientId!,
                           zendeskUrl: url!)
        Support.initialize(withZendesk: Zendesk.instance)
        
        let ident = Identity.createAnonymous()
        Zendesk.instance?.setIdentity(ident)
        
        let hcConfig = HelpCenterUiConfiguration()
        hcConfig.groupType = .section
        hcConfig.groupIds = [1234, 5678]
        
        self.helpCenter = HelpCenterUi.buildHelpCenterOverviewUi(withConfigs: [hcConfig])
        Theme.currentTheme.primaryColor = UIColor.orange

        
        if let navigationController = UIApplication.shared.keyWindow?.rootViewController as? UINavigationController {
            navigationController.pushViewController(helpCenter!, animated: true)
        }
        
        let storyboard : UIStoryboard? = UIStoryboard.init(name: "Main", bundle: nil);
        let window: UIWindow = ((UIApplication.shared.delegate?.window)!)!
        
        let objVC: UIViewController? = storyboard!.instantiateViewController(withIdentifier: "FlutterViewController")
        
        self.aObjNavi = UINavigationController(rootViewController: objVC!)
        window.rootViewController = self.aObjNavi
        self.aObjNavi!.pushViewController(self.helpCenter!, animated : true)
        
        flutterResult!("success")
    }
}
